Class: Rubygame::Event

Inherits:
Object
  • Object
show all
Defined in:
lib/rubygame/event.rb,
ext/rubygame/rubygame_event.c

Overview

if desired; inheriting this class is not necessary, but makes it easier to check if an object is an event or not.