Class: Rubygame::Events::QuitRequested

Inherits:
Object
  • Object
show all
Defined in:
lib/rubygame/events/misc_events.rb

Overview

QuitRequested is an event that occurs when the application receives a quit request, usually due to the user clicking the “Close” button on the app window.

Almost always, your application should respond to this event by quitting or by displaying a “Quit/Cancel” dialog. If you ignore this event, the user may become frustrated that your app won’t close properly!