Class: Rubygame::ExposeEvent

Inherits:
Event
  • Object
show all
Defined in:
lib/rubygame/event.rb

Overview

Indicates that part of the application window was exposed or otherwise changed, and perhaps the window needs to be refreshed. This event occurs, for example, when an OpenGL display should be updated.