Class: Rubygame::EventQueue
- Inherits:
-
Array
- Object
- Array
- Rubygame::EventQueue
- Defined in:
- lib/rubygame/queue.rb
Overview
EventQueue to help manage the game state.
For basic usage, create a #new EventQueue with autofetch, then call the #each method once per game loop, passing a block which handles events. See the sample applications for examples of this.
In Rubygame 2.4 and later, you can call #enable_new_style_events to make EventQueue fetch the new event classes (in the Rubygame::Events module). Otherwise, the old classes will be used, for backwards compatibility.
It is **strongly recommended** that you use the new event classes. The old classes are deprecated as of Rubygame 2.4, and will be removed entirely in Rubygame 3.0.
If you wish to ignore all events of a certain class, append those classes the instance variable @ignore (accessors are provided). You can ignore as many classes of events as you want, but make sure you don’t ignore ALL event classes, or the user won’t be able to control the game!
If the program has to pause and wait for an event (for example, if the player must press a button to begin playing), you might find the #wait method to be convenient.
Instance Attribute Summary collapse
-
#autofetch ⇒ Object
Whether to fetch SDL events automatically when #each and #wait are used.
-
#ignore ⇒ Object
Array of classes to be ignored by #push.
Instance Method Summary collapse
-
#each(&block) ⇒ Object
Iterate through all events in the EventQueue, yielding them one at a time to the given block.
-
#enable_new_style_events ⇒ Object
Enable new-style events.
-
#fetch_sdl_events ⇒ Object
Posts pending SDL hardware events to the EventQueue.
-
#initialize {|_self| ... } ⇒ EventQueue
constructor
Create a new EventQueue.
-
#peek_each(&block) ⇒ Object
Like #each, but doesn’t remove the events from the queue after iterating.
-
#push(*events) ⇒ Object
(also: #post)
Append events to the EventQueue.
-
#wait(delay = 10, &block) ⇒ Object
Wait for an event to be posted, then return that event.
Constructor Details
#initialize {|_self| ... } ⇒ EventQueue
Create a new EventQueue.
63 64 65 66 67 68 |
# File 'lib/rubygame/queue.rb', line 63 def initialize() @autofetch = true @ignore = [] @new_style_events = false yield self if block_given? end |
Instance Attribute Details
#autofetch ⇒ Object
Whether to fetch SDL events automatically when #each and #wait are used. Enabled by default.
60 61 62 |
# File 'lib/rubygame/queue.rb', line 60 def autofetch @autofetch end |
#ignore ⇒ Object
Array of classes to be ignored by #push.
56 57 58 |
# File 'lib/rubygame/queue.rb', line 56 def ignore @ignore end |
Instance Method Details
#each(&block) ⇒ Object
Iterate through all events in the EventQueue, yielding them one at a time to the given block. The EventQueue is flushed after all events have been yielded. You can use #peek_each if you want to keep the events.
If the internal variable @autofetch is true, this method will call #fetch_sdl_events once before iterating.
108 109 110 111 112 |
# File 'lib/rubygame/queue.rb', line 108 def each( &block ) fetch_sdl_events if @autofetch _old_each( &block ) self.clear end |
#enable_new_style_events ⇒ Object
Enable new-style events. These are the event classes in the Rubygame::Events module, which were added in Rubygame 2.4.
If you call this method, the new event classes will be used. Otherwise, the old classes will be used, for backwards compatibility.
It is **strongly recommended** that you use the new event classes. The old classes are deprecated as of Rubygame 2.4, and will be removed entirely in Rubygame 3.0.
82 83 84 |
# File 'lib/rubygame/queue.rb', line 82 def enable_new_style_events @new_style_events = true end |
#fetch_sdl_events ⇒ Object
Posts pending SDL hardware events to the EventQueue. Only one EventQueue should call this method per application, and only if you are not using Rubygame#fetch_sdl_events to manually process events! Otherwise, some events may be removed from SDL’s event stack before they can be properly processed!
127 128 129 130 131 132 133 134 135 |
# File 'lib/rubygame/queue.rb', line 127 def fetch_sdl_events if @new_style_events self.push( Rubygame::Events.fetch_sdl_events() ) else Rubygame.deprecated("Rubygame::EventQueue with old event classes", "3.0") self.push( Rubygame.fetch_sdl_events() ) end end |
#peek_each(&block) ⇒ Object
Like #each, but doesn’t remove the events from the queue after iterating.
116 117 118 119 |
# File 'lib/rubygame/queue.rb', line 116 def peek_each( &block ) fetch_sdl_events if @autofetch _old_each( &block ) end |
#push(*events) ⇒ Object Also known as: post
Append events to the EventQueue. Silently ignores events whose class is in @ignore.
89 90 91 92 93 94 |
# File 'lib/rubygame/queue.rb', line 89 def push(*events) events = events.flatten.delete_if {|e| @ignore.include?(e.class)} events.each do |e| super( e ) end end |
#wait(delay = 10, &block) ⇒ Object
Wait for an event to be posted, then return that event. If there is already an event in the queue, this method will immediately return that event. Events that are ignored will not trigger the return.
This method takes this argument:
- time
-
how long (in milliseconds) to delay between each check for new events. Defaults to 10 ms.
If a block is given to this method, it will be run after each unsuccessful check for new events. This method will pass to the block the number of times it has checked for new events.
If the internal variable @autofetch is true, this method will call #fetch_sdl_events before every check for new events.
Please be cautious when using this method, as it is rather easy to cause an infinite loop. Two ways an infinite loop might occur are:
-
Waiting for an SDL event when @autofetch is disabled. (This is not a problem if the block will post an event.)
-
Waiting for any event when all possible event types are ignored.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/rubygame/queue.rb', line 159 def wait(delay=10, &block) iterations = 0 if block_given? loop do fetch_sdl_events() if @autofetch if self.length >= 1 s = self.shift return s unless s == nil end yield iterations iterations += 1 Rubygame::Clock.delay(delay) end else loop do fetch_sdl_events() if @autofetch s = self.shift return s unless s == nil iterations += 1 Rubygame::Clock.delay(delay) end end end |