Class: Rubygame::Events::MouseReleased
- Inherits:
-
Object
- Object
- Rubygame::Events::MouseReleased
- Includes:
- MouseButtonEvent
- Defined in:
- lib/rubygame/events/mouse_events.rb
Overview
MouseReleased is an event class which occurs when a button on the mouse is released (no longer being pressed).
This class gains #button and #pos attribute readers from the MouseButtonEvent mixin module.
Instance Attribute Summary
Attributes included from MouseButtonEvent
Instance Method Summary collapse
-
#initialize(pos, button) ⇒ MouseReleased
constructor
Create a new MouseReleased instance.
Constructor Details
#initialize(pos, button) ⇒ MouseReleased
Create a new MouseReleased instance.
- button
-
a symbol for the button that was pressed or released. (Symbol, required)
- pos
-
an Array for the position of the mouse cursor when the event occured. [0,0] is the top-left corner of the window (or the screen if running full-screen). (Array, required)
109 110 111 |
# File 'lib/rubygame/events/mouse_events.rb', line 109 def initialize( pos, ) super end |